@@ -20,6 +20,7 @@ import logging
 import wrapt
 import hashlib
 from lxml import etree
+from pymysql.converters import escape_string
 
 from random import choice
 
@@ -316,7 +317,7 @@ class Tool:
                         values.append('%s' % data[i])
                     elif isinstance(data[i], str):
                         key.append(i)
-                        values.append('"%s"' % pymysql.escape_string(data[i]))
+                        values.append('"%s"' % escape_string(data[i]))
                     elif data[i] or data[i] == 0:
                         key.append(i)
                         values.append('"%s"' % data[i])
@@ -676,9 +677,9 @@ class Tool:
             if type == "install":
                 key = item.keys()
                 value = item.values()
-                return ", ".join(key), ", ".join(["\"{}\"".format(pymysql.escape_string(v) if isinstance(v, str) else v) for v in value])
+                return ", ".join(key), ", ".join(["\"{}\"".format(escape_string(v) if isinstance(v, str) else v) for v in value])
             elif type == "update":
-                str_list = ["{}=\"{}\"".format(k, pymysql.escape_string(v) if isinstance(v, str) else v) for k, v in item.items()]
+                str_list = ["{}=\"{}\"".format(k, escape_string(v) if isinstance(v, str) else v) for k, v in item.items()]
                 return ", ".join(str_list)
 
         insert_url = """INSERT INTO {} ({}) VALUES ({}) ON DUPLICATE KEY UPDATE {}"""
@@ -727,7 +728,7 @@ class Tool:
                 if isinstance(value, int) or isinstance(value, float) or isinstance(value, bytes):
                     value = '%s' % value
                 elif isinstance(value, str):
-                    value = '"%s"' % pymysql.escape_string(value)
+                    value = '"%s"' % escape_string(value)
                 elif value or value == 0:
                     value = '"%s"' % value
                 values.append(value)
